cmoncrawl.processor.pipeline.router.Router.load\_module
=======================================================

.. currentmodule:: cmoncrawl.processor.pipeline.router

.. automethod:: Router.load_module